from flask import Blueprint
from flask import render_template
from app_editor import get_logger
from app_editor.py.api.rest_api import api_blueprint


logger = get_logger()

if logger.is_enabled():
    logger.debug('editor: Instantiating editor blueprints')


class NestableBlueprint(Blueprint):
    """
    Extended blueprint, allows for additional blueprints to be registered
    """

    def add_nested_blueprint(self, blueprint):
        """
        Function to add a nested blueprint
        """
        blueprint.url_prefix = self.url_prefix + blueprint.url_prefix

        if logger.is_enabled():
            logger.debug('add_nested_blueprint(): Adding nested blueprint '
                         '[%s] to the app editor.' % blueprint.name)

        def later(state):
            state.app.register_blueprint(blueprint)

        self.record(later)


editor_blueprint = NestableBlueprint('app_editor',
                             __name__,
                             template_folder='templates',
                             static_folder='static',
                             static_url_path='/app_editor/static',
                             url_prefix='/app_editor')

editor_blueprint.add_nested_blueprint(api_blueprint)


@editor_blueprint.route('/editor')
def editor():
    return render_template('editor/editor.html')
