import functools
import sys
import traceback
import flask

from flask import render_template


def failsafe(func):

    @functools.wraps(func)
    def function_wrapper(*args, **kwargs):
        extra_files = []
        traceback_list = None

        try:
            return func(*args, **kwargs)
        except:
            exception_type, exception_value, exception_traceback = sys.exc_info()
            traceback.print_exc()
            traceback_list = traceback.format_exception(exception_type, exception_value, exception_traceback)

        tb = exception_traceback
        while tb:
            filename = tb.tb_frame.f_code.co_filename
            extra_files.append(filename)
            tb = tb.tb_next

        if isinstance(exception_value, SyntaxError):
            extra_files.append(exception_value.filename)

        app = _FailSafe_Runner(extra_files)
        app.debug = True

        if not isinstance(exception_type, str):
            exception_type = exception_type.__name__

        buf = traceback.format_exception_only(exception_type, exception_value)
        rv = ''.join(buf).strip()
        exception = rv.decode('utf-8', 'replace')

        @app.route('/')
        @app.route('/<path:path>')
        def index(path='/'):
            data = {
            "exception_type" : exception_type,
            "exception" : exception,
            "traceback" : traceback_list
            }
            return render_template('editor/exception.html', data = data)

        return app
    return function_wrapper


class _FailSafe_Runner(flask.Flask):

    def __init__(self, extra_files):
        flask.Flask.__init__(self, __name__)
        self.extra_files = extra_files

    def run(self, *args, **kwargs):
        extra_files = self.extra_files
        if 'extra_files' in kwargs:
            extra_files = extra_files + kwargs['extra_files']
        kwargs['extra_files'] = extra_files
        flask.Flask.run(self, *args, **kwargs)
