
def to_json_dict(python_obj, classkey=None):
    """
    Helper function to convert a Python object into a dict
    usable with the JSON REST.
    Recursively converts fields which are also Python objects.
    @param python_obj: Python object to be converted into a dict
    @return dict object containing key:value pairs for the python
    objects fields. Usable with JSON REST.
    """
    if isinstance(python_obj, dict):
        data = {}
        for (k, v) in python_obj.items():
            data[k] = to_json_dict(v, classkey)
        return data
    elif hasattr(python_obj, "_ast"):
        return to_json_dict(python_obj._ast())
    elif hasattr(python_obj, "__iter__"):
        return [to_json_dict(v, classkey) for v in python_obj]
    elif hasattr(python_obj, "__dict__"):
        data = dict([(key, to_json_dict(value, classkey))
                    for key, value in python_obj.__dict__.iteritems()
                    if not callable(value) and not key.startswith('_')])
        if classkey is not None and hasattr(python_obj, "__class__"):
            data[classkey] = python_obj.__class__.__name__
        return data
    else:
        return python_obj
