from pip import main
from flask import jsonify

editor_deps = '/app_editor/editor_deps'
editor_pip = editor_deps + '/pip'
editor_pip_reqs = editor_pip + '/requirements.txt'

main(["install", "-r", editor_pip_reqs])

from app_editor.editor import editor_blueprint
from app_editor.py.api.rest_api import ApiException

def scoped_create_app():
    from app_editor.py.utils.exception_handler import failsafe

    @failsafe
    def create_app():
        from app import app
        return app

    return create_app()

app = scoped_create_app()

if '/debug' not in app.url_map.iter_rules():
    @app.route('/debug')
    def dummy_debug():
        return ('', 200)

app.register_blueprint(editor_blueprint)
app.jinja_env.auto_reload = True

@app.errorhandler(ApiException)
def handle_invalid_usage(error):
    response = jsonify(error.to_dict())
    response.status_code = error.status_code
    return response

app.run(host='0.0.0.0', threaded=True, debug=True)
